OnchainDkgOutcome

Struct OnchainDkgOutcome 

pub struct OnchainDkgOutcome {
    pub epoch: Epoch,
    pub output: Output<MinSig, PublicKey>,
    pub next_players: Set<PublicKey>,
    pub is_next_full_dkg: bool,
}
The outcome of a DKG ceremony as it is written to the chain.

This DKG outcome can encode up to u16::MAX validators. Note that in practice this far exceeds the maximum size permitted header size and so is likely out of reach.

Fields

epoch: Epoch

The epoch for which this outcome is used.

output: Output<MinSig, PublicKey>

The output of the DKG ceremony. Contains the shared public polynomial, and the players in the ceremony (which will be the dealers for the epoch encoded with this output).

next_players: Set<PublicKey>

The next players. These will be the players in the DKG ceremony running during epoch.

is_next_full_dkg: bool

Whether the next DKG ceremony should be a full ceremony (new polynomial) instead of a reshare. Set when nextFullDkgCeremony == epoch.

Implementations

Source

impl OnchainDkgOutcome

pub fn dealers(&self) -> &Set<PublicKey>

pub fn players(&self) -> &Set<PublicKey>

pub fn next_players(&self) -> &Set<PublicKey>

pub fn sharing(&self) -> &Sharing<MinSig>

pub fn network_identity(&self) -> &<MinSig as Variant>::Public